@@ -5,7 +5,7 @@
 
 package Alien::unibilium;
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 
 use POSIX qw( WEXITSTATUS );
 
@@ -87,12 +87,6 @@ sub _get_pkgconfig
    return $ret;
 }
 
-sub libs
-{
-   # Append RPATH so that runtime linking actually works
-   return _get_pkgconfig( libs => @_ ) . ( $use_bundled ? " -Wl,-R$libdir" : "" );
-}
-
 =head1 SEE ALSO
 
 =over 4
